@@ -439,9 +439,9 @@ emmeans = function(object, specs, by = NULL,
                 fac.reduce(RG@linfct[idx, , drop=FALSE])
             })
         
-        linfct = t(matrix(K, nrow = ncol(RG@linfct)))
-        row.names(linfct) = NULL
-        
+        linfct = t(matrix(K, nrow = ncol(RG@linfct),
+                          dimnames = list(colnames(RG@linfct), NULL)))
+
         if(.some.term.contains(union(facs, RG@roles$trend), RG@model.info$terms))
             if(get_emm_option("msg.interaction"))
                 message("NOTE: Results may be misleading due ", 
